# IdentityAssertionResponse

The results of a successful identity assertion

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_id** | **str** | The user id specified by the identity assertion | [optional] 
**email** | **str** | The email of the user specified by the identity assertion | [optional] 
**username** | **str** | The username of the user specified by the identity assertion. This is a combination of the user&#39;s first and last name in the form &#x60;first last&#x60;. | [optional] 
**org_id** | **str** | The org id specified by the identity assertion | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


